@@ -15,7 +15,7 @@ async fn shutdown_signal() {
 }
 
 #[derive(Clone)]
-struct LogHandler {}
+struct LogHandler;
 
 #[async_trait]
 impl HttpHandler for LogHandler {
@@ -50,7 +50,7 @@ async fn main() {
         .with_addr(SocketAddr::from(([127, 0, 0, 1], 3000)))
         .with_rustls_client()
         .with_ca(ca)
-        .with_http_handler(LogHandler {})
+        .with_http_handler(LogHandler)
         .build();
 
     if let Err(e) = proxy.start(shutdown_signal()).await {
